import os
import unittest

from xmlrunner import XMLTestRunner

from pyquet.modules.schemas import Reader


class ReaderTestCase(unittest.TestCase):
    def setUp(self):
        self.schemas_path = os.path.join(os.path.dirname(__file__), "test_data", "schemas")
        self.schemas_path_without_schemas = os.path.join(self.schemas_path, "data")
        self.schema_1 = os.path.join(self.schemas_path, 'schema_1.json')
        self.schema_2 = os.path.join(self.schemas_path, 'schema_2.json')
        self.schema_3 = os.path.join(self.schemas_path, 'schema_3.json')
        self.schemas_list = [self.schema_1, self.schema_2, self.schema_3]
        self.bad_schema = os.path.join(self.schemas_path, 'not_schema.txt')

    def test_single_file(self):
        self.reader = Reader(os.path.join(self.schema_1))
        self.assertDictEqual(self.reader.schemas_dict[self.schema_1], {"test": "data1"})

    def test_directory(self):
        self.reader = Reader(self.schemas_path)
        self.assertDictEqual(self.reader.schemas_dict[self.schema_1], {"test": "data1"})
        self.assertDictEqual(self.reader.schemas_dict[self.schema_2], {"test": "data2"})
        self.assertDictEqual(self.reader.schemas_dict[self.schema_3], {"test": "data3"})

    def test_directory_without_schemas(self):
        self.reader = Reader(self.schemas_path_without_schemas)
        self.assertDictEqual(self.reader.schemas_dict, {})

    def test_array(self):
        self.reader = Reader(self.schemas_list)
        self.assertDictEqual(self.reader.schemas_dict[self.schema_1], {"test": "data1"})
        self.assertDictEqual(self.reader.schemas_dict[self.schema_2], {"test": "data2"})
        self.assertDictEqual(self.reader.schemas_dict[self.schema_3], {"test": "data3"})

    def test_invalid_file(self):
        self.reader = Reader(self.bad_schema)
        self.assertDictEqual(self.reader.schemas_dict, {})

    def test_invalid_input_type(self):
        self.reader = Reader(123)
        self.assertDictEqual(self.reader.schemas_dict, {})


if __name__ == '__main__':
    with open('test-reports/results.xml', 'wb') as output:
        unittest.main(testRunner=XMLTestRunner(output=output), verbosity=2)



import copy
import shutil
import traceback

import pandas as pd
import pyarrow as pa

pd.set_option('display.width', None)
pd.set_option('display.max_colwidth', None)
pd.set_option('display.max_columns', None)
pd.set_option('display.max_rows', None)


class FieldNotFoundException(Exception):
    def __init__(self, field):
        self.field = field
        self.message = f"Field '{field}' not found in the schema."
        super().__init__(self.message)


class TableEditor:
    def __init__(self, path, schema, partitions):
        self.path = path
        self.df = pd.read_parquet(self.path)
        self.schema = schema
        self.tmp_path = path + "_tmp"
        self.partitions = partitions

    def backup_table(self):
        shutil.copytree(self.path, self.tmp_path)

    def set_constants(self, map_dict):
        self.backup_table()
        df = copy.deepcopy(self.df)
        try:
            for column, value in map_dict.items():
                if column not in self.df.columns:
                    raise FieldNotFoundException(column)
                print(type(df[column]))
                df[column] = value
            table = pa.Table.from_pandas(df)
            table = table.cast(self.schema)
            shutil.rmtree(self.path)
            pq.write_to_dataset(df, self.path, partition_cols=self.partitions)
            self.df = df
        except FieldNotFoundException as e:
            shutil.rmtree(self.path, ignore_errors=True)
            shutil.copytree(self.tmp_path, self.path)
            traceback.print_exc()
        except Exception as e:
            shutil.rmtree(self.path, ignore_errors=True)
            shutil.copytree(self.tmp_path, self.path)
            traceback.print_exc()
        finally:
            shutil.rmtree(self.tmp_path)
            return self.df



import os.path
import shutil

import pandas as pd
import tkinter as tk

import traceback
import pyarrow as pa
import pyarrow.parquet as pq
from tkinter import filedialog
from pandastable import Table, TableModel


class CustomTable(Table):
    def __init__(self, parent=None, **kwargs):
        Table.__init__(self, parent, **kwargs)
        self.partitions = []
        self.file_path = None
        self.schema = None

    def load_csv(self):
        self.file_path = filedialog.askdirectory()
        if self.file_path:
            try:
                df = pd.read_parquet(self.file_path, dtype_backend="pyarrow")
                self.schema = pa.Schema.from_pandas(df)
                self.partitions = [field.name for field in self.schema if isinstance(field.type, pa.DictionaryType)]
                transformed_fields = [
                    pa.field(field.name, pa.string())
                    if field.type == pa.dictionary(pa.int32(), pa.string()) else field
                    for field in self.schema
                ]
                self.schema = pa.schema(transformed_fields)
                df_string = pd.read_parquet(self.file_path)
                self.updateModel(TableModel(df_string))
            except pd.errors.ParserError:
                print("Invalid file.")
            except Exception as e:
                print("An error occurred:", e)
                print(traceback.print_exc())

    def save_csv(self):
        if self.file_path:
            file_path = filedialog.askdirectory()
        else:
            file_path = filedialog.askdirectory()
        if file_path:
            try:
                if os.path.exists(file_path):
                    shutil.rmtree(file_path)
                df = self.model.df
                pa_table = pa.Table.from_pandas(df)
                pa_table = pa_table.cast(self.schema)
                pq.write_to_dataset(pa_table, file_path, partition_cols=self.partitions)
            except Exception as e:
                print("An error occurred:", e)
                print(traceback.print_exc())


class CustomToolbar(tk.Frame):
    def __init__(self, parent=None, parent_table=None, **kwargs):
        tk.Frame.__init__(self, parent, **kwargs)
        self.table = parent_table
        self.load_button = tk.Button(self, text="Load Table", command=self.load_csv)
        self.load_button.pack(side=tk.LEFT)
        self.save_button = tk.Button(self, text="Save Table", command=self.save_csv)
        self.save_button.pack(side=tk.LEFT)

    def load_csv(self):
        self.table.load_csv()
        self.table.redraw()

    def save_csv(self):
        self.table.save_csv()


def main():
    root = tk.Tk()

    table_frame = tk.Frame(root)
    table_frame.pack(fill=tk.BOTH, expand=True)

    table = CustomTable(table_frame)
    table.show()

    toolbar = CustomToolbar(root, parent_table=table)
    toolbar.pack(side=tk.TOP, fill=tk.X)

    root.mainloop()


main()



import unittest
import tempfile
import os
import json
from pyquet.modules.common import read_json, list_files
from xmlrunner import XMLTestRunner # noqa

class TestCommonFunctions(unittest.TestCase):

    def setUp(self):
        # Create a temporary directory
        self.test_dir = tempfile.TemporaryDirectory()
        self.test_file = os.path.join(self.test_dir.name, 'test.json')
        self.test_data = {"key": "value"}
        with open(self.test_file, 'w') as f:
            json.dump(self.test_data, f)

    def tearDown(self):
        # Cleanup the temporary directory
        self.test_dir.cleanup()

    def test_read_json(self):
        # Test reading a JSON file
        result = read_json(self.test_file)
        self.assertEqual(result, self.test_data)

    def test_list_files_no_regex(self):
        # Test listing files without regex
        result = list_files(self.test_dir.name)
        self.assertIn(self.test_file, result)

    def test_list_files_with_regex(self):
        # Test listing files with regex
        result = list_files(self.test_dir.name, r'.*\.json')
        self.assertIn(self.test_file, result)

    def test_list_files_with_regex_no_match(self):
        # Test listing files with regex that does not match
        result = list_files(self.test_dir.name, r'.*\.txt')
        self.assertNotIn(self.test_file, result)
        self.assertEqual(result, [])

if __name__ == '__main__':
    with open('test-reports/results.xml', 'wb') as output:
        unittest.main(testRunner=XMLTestRunner(output=output), verbosity=2)


import argparse
import json
import logging
import sys

from pyquet.modules.generator import DataGenerator


def main():
    logging.info("Running Pyquet generator...")
    parser = argparse.ArgumentParser(description="Pyquet generator")

    parser.add_argument("--schema-path",
                        "-s",
                        metavar="SCHEMA_PATH",
                        type=str,
                        help="Path to the schema file",
                        required=True)

    parser.add_argument("--output-type",
                        "-t",
                        metavar="OUTPUT_TYPE",
                        type=str,
                        help="Output type, parquet or csv",
                        required=True)

    parser.add_argument("--destination-dir",
                        "-d",
                        metavar="DESTINATION_DIR",
                        type=str,
                        help="Destination directory",
                        required=False,
                        default=None)

    parser.add_argument("--partitions",
                        "-p",
                        metavar="PARTITIONS",
                        type=str,
                        help="Partitions",
                        required=False)

    parser.add_argument("--catalog-path",
                        "-c",
                        metavar="CATALOG_PATH",
                        type=str,
                        help="Catalog path",
                        required=False)

    parser.add_argument("--num-rows",
                        "-r",
                        metavar="NUM_ROWS",
                        type=int,
                        help="Number of rows",
                        required=False,
                        default=10)

    parser.add_argument("--limit-rows",
                        "-l",
                        help="Limit rows",
                        required=False,
                        action='store_true')

    parser.add_argument("--fixed-values",
                        "-v",
                        metavar="FIXED_VALUES",
                        type=str,
                        help="Fixed values",
                        required=False)

    if len(sys.argv) == 1:
        parser.print_help()
        exit(0)

    args = parser.parse_args()

    generator = DataGenerator(args.catalog_path, args.num_rows, args.limit_rows)


    if args.fixed_values:
        args.fixed_values = args.fixed_values.replace("'", "\"")
        fixed_values = json.loads(args.fixed_values)
        generator.catalog.update(fixed_values)

    partitions = args.partitions.split(",")

    generator.generate_data(args.schema_path, args.output_type, partitions, args.destination_dir)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.md')) as f:
    readme = f.read()

# Extract the requirements from the deps file.
with open(os.path.join(here, "requirements.txt")) as f:
    requirements = [line.strip() for line in f if line.strip() and not line.startswith('#')]

with open(os.path.join(here, "requirements_dev.txt")) as f:
    test_requirements = [line.strip() for line in f if line.strip() and not line.startswith('#')]

setup(
    name='pyquet',
    version='1.0.3',
    description='Generate pseudorandom data from .json schemas',
    author='Ricardo Múgica',
    author_email='rmugicag@gmail.com',
    entry_points={
        "console_scripts": [
            "PyquetGenerate=pyquet.pyquet_generator:main"
        ]
    },
    install_requires=requirements,
    extras_require={
        'dev': test_requirements,
    },
    packages=find_packages(),
)